<?php

namespace Bixo\Map\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Map\Actions\ProjectAction;
use Bixo\Map\Http\Requests\ProjectActionRequest;
use Bixo\Map\Http\Resources\ProjectResource;
use Bixo\Map\Models\Project;

/**
 * Admin web controller class.
 */
class ProjectActionController extends BaseController
{

    /**
     * Action controller function for project.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProjectActionRequest $request, Project $project, $action)
    {
        try {
            $request = $request->all();
            $project = ProjectAction::run($action, $project, $request);

            $data = new ProjectResource($project);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('map::project.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('map/project/' . $project->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('map/project/' . $project->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
