<?php

namespace Bixo\Map\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Map\Actions\ProjectExim;
use Bixo\Map\Http\Requests\ProjectEximRequest;

/**
 * Admin web controller class.
 */
class ProjectEximController extends BaseController
{
    /**
     * Action controller function for project.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProjectEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ProjectExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('map:project.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('map/project/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('map/project/' . $exim))
                ->redirect();
        }
    }
}
