<?php

namespace Bixo\Map\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Map\Actions\TransactionAction;
use Bixo\Map\Http\Requests\TransactionActionRequest;
use Bixo\Map\Http\Resources\TransactionResource;
use Bixo\Map\Models\Transaction;

/**
 * Admin web controller class.
 */
class TransactionActionController extends BaseController
{

    /**
     * Action controller function for transaction.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TransactionActionRequest $request, Transaction $transaction, $action)
    {
        try {
            $request = $request->all();
            $transaction = TransactionAction::run($action, $transaction, $request);

            $data = new TransactionResource($transaction);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('map::transaction.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('map/transaction/' . $transaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('map/transaction/' . $transaction->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
