<?php

namespace Bixo\Map\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Map\Actions\TransactionExim;
use Bixo\Map\Http\Requests\TransactionEximRequest;

/**
 * Admin web controller class.
 */
class TransactionEximController extends BaseController
{
    /**
     * Action controller function for transaction.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TransactionEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = TransactionExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('map:transaction.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('map/transaction/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('map/transaction/' . $exim))
                ->redirect();
        }
    }
}
