<?php

namespace Bixo\Map\Http\Controllers;

use Exception;
use Bixo\Map\Actions\UnitWorkflow;
use Bixo\Map\Http\Requests\UnitWorkflowRequest;
use Bixo\Map\Http\Resources\UnitResource;
use Bixo\Map\Models\Unit;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class UnitWorkflowController extends BaseController
{
    /**
     * Action controller function for unit.
     *
     * @param Model $unit
     * @param action next action for the unit.
     *
     * @return Response
     */
    public function __invoke(UnitWorkflowRequest $request, Unit $unit, $trasition)
    {
        try {
            $request = $request->all();
            $unit = UnitWorkflow::run($trasition, $unit, $request);
            $data = new UnitResource($unit);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('map::unit.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('map/unit/' . $unit->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('map/unit/' . $unit->getRouteKey()))
                ->redirect();
        }
    }


    /**
     * Get the unit and user for the workflow.
     *
     * @param PublicRequest $request
     * @param string $unit
     * @param string $user
     *
     * @return Response
     */
    public function get(PublicRequest $request, $unit, $user)
    {
        if (!$request->hasValidSignature()) {
            abort(403, 'This url is expired!');
        }

        $auth = Auth::guard()->getProvider()->getModel();
        $user = $auth::findBySignedId($user);
        Auth::guard()->login($user);
        $unit = Unit::findBySignedId($unit);
        $transitions = $this->transitions($unit, $user);
        $user = user();
        Auth::logout();
        return $this->response->setMetaTitle(trans('map::unit.name') . ' ' . trans('Approvals'))
            ->view('map::public.unit.workflow')
            ->layout('mobile')
            ->data(compact('unit', 'user', 'transitions'))
            ->output();
    }

    /**
     * Display the workflow form for the unit.
     *
     * @param PublicRequest $request
     * @param string $unit
     * @param string $user
     *
     * @return Response
     */
    public function post(PublicRequest $request, $unit, $user)
    {
        if (!$request->hasValidSignature()) {
            abort(403, 'This url is expired!');
        }
        $transition = $request->transition;
        $auth = Auth::guard()->getProvider()->getModel();
        $user = $auth::findBySignedId($user);
        Auth::guard()->login($user);
        $unit = Unit::findBySignedId($unit);
        $user = user();
        $unit = UnitWorkflow::run($transition, $unit, $request->all());
        Auth::logout();

        return response()->json(
            [
                'status' => 'success',
                'url' => $request->url(),
            ]
        );
    }

    private function transitions($unit, $user)
    {
        $transitions = [];
        foreach ($unit->workflow()->transitions($unit) as $key => $value) {
            $name = $value->getName();
            $array['url'] = URL::temporarySignedRoute('litecms.unit.workflow', now()->addMinutes(3), [
                'guard' => 'admin',
                'transition' => $name,
                'unit' => $unit->getSignedId(now()->addMinutes(3)),
                'user' => $user->getSignedId(now()->addMinutes(3)),
                'trans' => 'en',
            ]
            );
            $array['name'] = $name;
            $array['key'] = $name;
            $array['form'] = $unit->workflow()->form($value);
            $array['label'] = trans('map::unit.workflow.' . $name);
            $transitions[] = $array;
        }
        return $transitions;
    }
}
