<?php

namespace Bixo\Map\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Map\Events\ProjectAction as ProjectActionEvent;
use Bixo\Map\Notifications\ProjectAction as ProjectActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ProjectAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ProjectActionEvent.
     *
     * @param   ProjectActionEvent  $event
     * @return mixed
     */
    public function handle(ProjectActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $project.
     *
     * @param   ProjectActionEvent  $event
     * @return void
     */
    public function create(ProjectActionEvent $event)
    {
        $client = $event->project->client;
        Notification::send($client, new ProjectActionNotification($event));
    }

    /**
     * Handle the ProjectActionEvent as a listener.
     *
     * @param   ProjectActionEvent  $event
     * @return mixed
     */
    public function asListener(ProjectActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ProjectActionEvent  $event
     * @return bool
     */
    private function isAllowed(ProjectActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
