<?php

namespace Bixo\Map\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Map\Events\ProjectWorkflow as ProjectWorkflowEvent;
use Bixo\Map\Notifications\ProjectWorkflow as ProjectWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ProjectWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ProjectWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $project is submitted.
     *
     * @param ProjectWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ProjectWorkflowEvent $event)
    {
        $client = $event->project->client;
        Notification::send($client, new ProjectWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $project is published.
     *
     * @param ProjectWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ProjectWorkflowEvent $event)
    {
        $client = $event->project->client;
        Notification::send($client, new ProjectWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $project is approved.
     *
     * @param ProjectWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ProjectWorkflowEvent $event)
    {
        $client = $event->project->client;
        Notification::send($client, new ProjectWorkflowNotification($event));
    }

    /**
     * Handles the $project workflow event as a listener.
     *
     * @param ProjectWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ProjectWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
