<?php

namespace Bixo\Map\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Map\Events\TransactionAction as TransactionActionEvent;
use Bixo\Map\Notifications\TransactionAction as TransactionActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TransactionAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TransactionActionEvent.
     *
     * @param   TransactionActionEvent  $event
     * @return mixed
     */
    public function handle(TransactionActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $transaction.
     *
     * @param   TransactionActionEvent  $event
     * @return void
     */
    public function create(TransactionActionEvent $event)
    {
        $client = $event->transaction->client;
        Notification::send($client, new TransactionActionNotification($event));
    }

    /**
     * Handle the TransactionActionEvent as a listener.
     *
     * @param   TransactionActionEvent  $event
     * @return mixed
     */
    public function asListener(TransactionActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TransactionActionEvent  $event
     * @return bool
     */
    private function isAllowed(TransactionActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
