<?php

namespace Bixo\Map\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Map\Events\TransactionWorkflow as TransactionWorkflowEvent;
use Bixo\Map\Notifications\TransactionWorkflow as TransactionWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TransactionWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TransactionWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $transaction is submitted.
     *
     * @param TransactionWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TransactionWorkflowEvent $event)
    {
        $client = $event->transaction->client;
        Notification::send($client, new TransactionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $transaction is published.
     *
     * @param TransactionWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TransactionWorkflowEvent $event)
    {
        $client = $event->transaction->client;
        Notification::send($client, new TransactionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $transaction is approved.
     *
     * @param TransactionWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TransactionWorkflowEvent $event)
    {
        $client = $event->transaction->client;
        Notification::send($client, new TransactionWorkflowNotification($event));
    }

    /**
     * Handles the $transaction workflow event as a listener.
     *
     * @param TransactionWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TransactionWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
