<?php

namespace Bixo\Map\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Map\Events\UnitAction as UnitActionEvent;
use Bixo\Map\Notifications\UnitAction as UnitActionNotification;
use Litepie\Actions\Concerns\AsAction;

class UnitAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the UnitActionEvent.
     *
     * @param   UnitActionEvent  $event
     * @return mixed
     */
    public function handle(UnitActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $unit.
     *
     * @param   UnitActionEvent  $event
     * @return void
     */
    public function create(UnitActionEvent $event)
    {
        $client = $event->unit->client;
        Notification::send($client, new UnitActionNotification($event));
    }

    /**
     * Handle the UnitActionEvent as a listener.
     *
     * @param   UnitActionEvent  $event
     * @return mixed
     */
    public function asListener(UnitActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   UnitActionEvent  $event
     * @return bool
     */
    private function isAllowed(UnitActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
