<?php
namespace Bixo\Map\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Map\Events\ProjectAction as ProjectActionEvent;
use Bixo\Map\Models\Project;

class ProjectAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $project;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ProjectActionEvent $project
     */
    public function __construct(ProjectActionEvent $project)
    {
        $this->action = $event->action;
        $this->project = $project;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Project Approved - ' . config('app.name'))
            ->view('map::project.email.action', ['data' => $this->project]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
