<?php
namespace Bixo\Map\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Map\Events\TransactionAction as TransactionActionEvent;
use Bixo\Map\Models\Transaction;

class TransactionAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $transaction;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TransactionActionEvent $transaction
     */
    public function __construct(TransactionActionEvent $transaction)
    {
        $this->action = $event->action;
        $this->transaction = $transaction;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Transaction Approved - ' . config('app.name'))
            ->view('map::transaction.email.action', ['data' => $this->transaction]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
