<?php

namespace Bixo\Map\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Map\Models\Project;

class ProjectPolicy
{

    use ProjectAction;
    use ProjectExim;
    use ProjectWorkflow;

    /**
     * Determine if the given user can view the project.
     *
     * @param Authenticatable $user
     * @param Project $project
     *
     * @return bool
     */
    public function view(Authenticatable $user, Project $project)
    {
        if ($authUser->canDo('map.project.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $project->is_owner;
    }

    /**
     * Determine if the given user can create a project.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('map.project.create');
    }

    /**
     * Determine if the given user can update the given project.
     *
     * @param Authenticatable $user
     * @param Project $project
     *
     * @return bool
     */
    public function update(Authenticatable $user, Project $project)
    {
        if ($user->canDo('map.project.edit') && $user->isAdmin()) {
            return true;
        }

        return $project->is_owner;
    }

    /**
     * Determine if the given user can delete the given project.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Project $project)
    {
        return $project->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
