<?php

namespace Bixo\Map\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Map\Models\Transaction;

class TransactionPolicy
{

    use TransactionAction;
    use TransactionExim;
    use TransactionWorkflow;

    /**
     * Determine if the given user can view the transaction.
     *
     * @param Authenticatable $user
     * @param Transaction $transaction
     *
     * @return bool
     */
    public function view(Authenticatable $user, Transaction $transaction)
    {
        if ($authUser->canDo('map.transaction.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $transaction->is_owner;
    }

    /**
     * Determine if the given user can create a transaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('map.transaction.create');
    }

    /**
     * Determine if the given user can update the given transaction.
     *
     * @param Authenticatable $user
     * @param Transaction $transaction
     *
     * @return bool
     */
    public function update(Authenticatable $user, Transaction $transaction)
    {
        if ($user->canDo('map.transaction.edit') && $user->isAdmin()) {
            return true;
        }

        return $transaction->is_owner;
    }

    /**
     * Determine if the given user can delete the given transaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Transaction $transaction)
    {
        return $transaction->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
