<?php

namespace Bixo\Map\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Map\Models\Unit;

class UnitPolicy
{

    use UnitAction;
    use UnitExim;
    use UnitWorkflow;

    /**
     * Determine if the given user can view the unit.
     *
     * @param Authenticatable $user
     * @param Unit $unit
     *
     * @return bool
     */
    public function view(Authenticatable $user, Unit $unit)
    {
        if ($authUser->canDo('map.unit.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $unit->is_owner;
    }

    /**
     * Determine if the given user can create a unit.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('map.unit.create');
    }

    /**
     * Determine if the given user can update the given unit.
     *
     * @param Authenticatable $user
     * @param Unit $unit
     *
     * @return bool
     */
    public function update(Authenticatable $user, Unit $unit)
    {
        if ($user->canDo('map.unit.edit') && $user->isAdmin()) {
            return true;
        }

        return $unit->is_owner;
    }

    /**
     * Determine if the given user can delete the given unit.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Unit $unit)
    {
        return $unit->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
