<?php

namespace Bixo\Map\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Map\Maps;

class MapServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'map');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'map');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Map\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Map\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Map\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Map\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\Map\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.map', function($app)
        {
            return $this->app->make(Map::class);
        });
    }

    /**
     * Merges user's and map's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.map'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/transaction.php', 'bixo.map.transaction'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/project.php', 'bixo.map.project'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/building.php', 'bixo.map.building'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/developer.php', 'bixo.map.developer'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/unit.php', 'bixo.map.unit'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.map'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/map')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/map')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/map')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
