<?php

namespace Bixo\Map\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Map\Models\Transaction;
use Bixo\Map\Models\Project;
use Bixo\Map\Models\Building;
use Bixo\Map\Models\Developer;
use Bixo\Map\Models\Unit;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Map\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/map/transaction/*')) {
            Route::bind('transaction', function ($transaction) {
                return Transaction::findorNew($transaction);
            });
        }
        if (Request::is('*/map/project/*')) {
            Route::bind('project', function ($project) {
                return Project::findorNew($project);
            });
        }
        if (Request::is('*/map/building/*')) {
            Route::bind('building', function ($building) {
                return Building::findorNew($building);
            });
        }
        if (Request::is('*/map/developer/*')) {
            Route::bind('developer', function ($developer) {
                return Developer::findorNew($developer);
            });
        }
        if (Request::is('*/map/unit/*')) {
            Route::bind('unit', function ($unit) {
                return Unit::findorNew($unit);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
